@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.1101';
+our $VERSION = '0.1102';
 
 use v5.36;
 
@@ -370,7 +370,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.1101
+version 0.1102
 
 =head1 SYNOPSIS
 
@@ -608,7 +608,8 @@ If the B<halt> attribute is set to true, the running filter will stop.
   $control->add_filter('flicker', all => $filter->curry::flicker);
 
 This filter toggles a B<control> change message, over the MIDI
-B<channel>, on (C<127>) and off (C<0>).
+B<channel>, between the B<range_bottom> ("off") and the B<range_top>
+("on").
 
 If B<trigger> or B<value> is set, the filter checks those against the
 MIDI event C<note> or C<value>, respectively, to see if the filter
